@@ -6,10 +6,11 @@ Minitest::Test.class_eval do
   alias_method :run_without_around, :run
   def run(*args)
     if defined?(around)
-      around { run_without_around(*args) }
+      result = nil
+      around { result = run_without_around(*args) }
+      result
     else
       run_without_around(*args)
     end
-    self
   end
 end
